@@ -337,10 +337,11 @@ class Output(ChoiceArgument):
     """Meta API call option 'output'"""
 
     def __init__(self):
-        super().__init__(["output"], choices=["html", "json"], default="html",
+        super().__init__(["output"], choices=["html", "plain", "json"], default="html",
                          doc=("Desired result format\n"
                               "\n"
                               "html: Return result as HTML (popup with JS, else full HTML page)\n"
+                              "plain: Plain result\n"
                               "json: Return raw json result\n"))
 
 
