@@ -6,12 +6,7 @@ import re
 
 import debian.deb822
 
-import mini_buildd.config
-import mini_buildd.misc
-import mini_buildd.files
-import mini_buildd.sbuild
-import mini_buildd.dist
-import mini_buildd.net
+from mini_buildd import config, events, util, files, sbuild, dist, net
 
 LOG = logging.getLogger(__name__)
 
@@ -21,12 +16,12 @@ class Base(debian.deb822.Changes):
         self.file_path = None
         if isinstance(initial_value, str):
             self.file_path = initial_value
-            with mini_buildd.fopen(initial_value) as cf:
+            with util.fopen(initial_value) as cf:
                 super().__init__(cf)
         else:
             super().__init__(initial_value)
 
-        self.dfn = mini_buildd.files.DebianName(self["Source"], self["Version"])
+        self.dfn = files.DebianName(self["Source"], self["Version"])
 
     def __str__(self):
         """Superclass would show all values multiline, so we need to replace with s.th. less invasive"""
@@ -43,7 +38,7 @@ class Base(debian.deb822.Changes):
 
     def add_file(self, file_name):
         self.setdefault("Files", [])
-        self["Files"].append({"md5sum": mini_buildd.misc.Hash(file_name).md5(),
+        self["Files"].append({"md5sum": util.Hash(file_name).md5(),
                               "size": os.path.getsize(file_name),
                               "section": "mini-buildd",
                               "priority": "extra",
@@ -56,11 +51,11 @@ class Base(debian.deb822.Changes):
         return os.path.exists(self.upload_file_path())
 
     def _upload(self, ftp_cls, endpoint, force=False):
-        pre_upload_timestamp = mini_buildd.misc.Datetime.now()
+        pre_upload_timestamp = util.Datetime.now()
 
         upload = self.upload_file_path()
         if not force and os.path.exists(upload):
-            with mini_buildd.fopen(upload) as uf:
+            with util.fopen(upload) as uf:
                 LOG.warning(f"FTP: '{upload}' exists (already uploaded to '{uf.read()}')")
         else:
             with ftp_cls() as ftp:
@@ -75,7 +70,7 @@ class Base(debian.deb822.Changes):
                     LOG.debug(f"FTP: Uploading file: '{f}'")
                     with open(os.path.join(os.path.dirname(self.file_path), f), "rb") as fi:
                         ftp.storbinary(f"STOR {f}", fi)
-                with mini_buildd.fopen(upload, "w") as fi:
+                with util.fopen(upload, "w") as fi:
                     fi.write(endpoint.geturl())
                 LOG.info(f"FTP: '{self.file_name()}' uploaded to '{endpoint.geturl()}'.")
 
@@ -85,19 +80,17 @@ class Base(debian.deb822.Changes):
         return self._upload(ftplib.FTP_TLS if endpoint.is_ssl() else ftplib.FTP, endpoint, force=force)
 
     def tar(self):
-        files = [os.path.join(os.path.dirname(self.file_path), f) for f in self.get_files("name")] + [self.file_path]
-        return mini_buildd.files.Tar().add(files)
+        _files = [os.path.join(os.path.dirname(self.file_path), f) for f in self.get_files("name")] + [self.file_path]
+        return files.Tar().add(_files)
 
     def untar(self, dir_path):
-        mini_buildd.files.Tar.extract(self.file_path + ".tar", dir_path)
+        files.Tar.extract(self.file_path + ".tar", dir_path)
 
     def save_as(self, file_path, gnupg=None):
-        """
-        Write to file (optionally signed)
-        """
+        """Write to file (optionally signed)"""
         LOG.debug(f"Saving changes: {file_path}")
         os.makedirs(os.path.dirname(file_path), exist_ok=True)  # Be sure base dir is always available
-        with open(file_path, "w+", encoding=mini_buildd.config.CHAR_ENCODING) as f:
+        with open(file_path, "w+", encoding=config.CHAR_ENCODING) as f:
             f.write(self.dump())
         if gnupg is not None:
             LOG.debug(f"Signing changes: {file_path}")
@@ -105,9 +98,7 @@ class Base(debian.deb822.Changes):
         self.file_path = file_path
 
     def _move_to(self, path):
-        """
-        Move changes file along with all accompanying files (needs ``file_path`` to be non-None)
-        """
+        """Move changes file along with all accompanying files (needs ``file_path`` to be non-None)"""
         LOG.debug(f"Moving changes: '{self.file_path}'->'{path.full}'")
         for fd in [{"name": self.file_name()}] + self.get_files():
             f = fd["name"]
@@ -124,7 +115,7 @@ class Changes(Base):
 
     @classmethod
     def match(cls, file_path):
-        return re.compile(f"^.+{mini_buildd.files.DebianName.uext(cls.FILE_APX)}_[^_]+.changes$").match(file_path)
+        return re.compile(f"^.+{files.DebianName.uext(cls.FILE_APX)}_[^_]+.changes$").match(file_path)
 
     def __init__(self, initial_value):
         super().__init__(initial_value)
@@ -132,30 +123,30 @@ class Changes(Base):
         for key, hint in self.MANDATORY.items():
             if key not in self:
                 hint_apx = f" ({hint})" if hint else ""
-                raise mini_buildd.HTTPBadRequest(f"Changes missing mandatory key: {key}{hint_apx}")
+                raise util.HTTPBadRequest(f"Changes missing mandatory key: {key}{hint_apx}")
 
-        self._timecode = mini_buildd.misc.Datetime.timecode()
+        self._timecode = util.Datetime.timecode()
 
         #: Key to identify if a 'Package' (Upload, Buildrequest, Buildresult).
         self.key = os.path.join(self["Source"], self["Version"], self.timecode)
         #: Key to identify a 'Build' (Buildrequest, Buildresult).
         self.bkey = os.path.join(self.key, self["Architecture"])
 
-        self.events_path = mini_buildd.config.ROUTES["events"].path.new_sub([self.bkey])
-        self.builds_path = mini_buildd.config.ROUTES["builds"].path.new_sub([self.bkey])
+        self.events_path = config.ROUTES["events"].path.new_sub([self.bkey])
+        self.builds_path = config.ROUTES["builds"].path.new_sub([self.bkey])
 
     @property
     def timecode(self):
         return self.cget("Timecode", self._timecode)
 
     def cget(self, field, default=None):
-        return self.get(mini_buildd.misc.CField(field).fullname, default=default)
+        return self.get(util.CField(field).fullname, default=default)
 
     def cset(self, field, value):
-        self[mini_buildd.misc.CField(field).fullname] = value
+        self[util.CField(field).fullname] = value
 
     def fields(self):
-        return {mini_buildd.misc.Field(field): value for field, value in self.items()}
+        return {util.Field(field): value for field, value in self.items()}
 
     def to_event_json(self):
         return {
@@ -174,7 +165,7 @@ class Changes(Base):
             tar_path = file_path + ".tar"
             tar.save_as(tar_path)
             self.add_file(tar_path)
-        self.save_as(file_path, mini_buildd.get_daemon().gnupg)
+        self.save_as(file_path, util.daemon().gnupg)
 
     def create_events(self):
         self.events_path.create()
@@ -196,9 +187,9 @@ class Changes(Base):
 class Upload(Changes):
     class Options():
         """
-        Uploader options in changes.
+        Uploader options in changes
 
-        >>> mini_buildd.config.ROUTES = mini_buildd.config.Routes("./test-data/home")   # We need ROUTES setup
+        >>> config.ROUTES = config.Routes("./test-data/home")   # We need ROUTES setup
 
         >>> f"{Upload.Options(Base('test-data/changes.options'))}"
         "auto-ports=['jessie-test-unstable', 'squeeze-test-snasphot'], autopkgtest-mode=errfail, internal-apt-priority=543, lintian-mode=errfail, piuparts-mode=errfail"
@@ -217,7 +208,7 @@ class Upload(Changes):
 
             def __init__(self, raw_value):
                 if raw_value.lower() not in self._VALID:
-                    raise Exception(f"Bool value must be one of {','.join(self._VALID)}")
+                    raise util.HTTPBadRequest(f"Bool value must be one of {','.join(self._VALID)}")
                 self.value = raw_value.lower() in self._TRUE
 
         class Int():
@@ -253,7 +244,7 @@ class Upload(Changes):
         @classmethod
         def usage(cls):
             return ("(lintian|piuparts|autopkgtest)-mode[<arch>]=<mode>\n"
-                    f"  {mini_buildd.dist.SbuildCheck.usage()}\n"
+                    f"  {dist.SbuildCheck.usage()}\n"
                     "internal-apt-priority[<arch>]=<prio>\n"
                     "  Apt prio for our repo packages when building (use 500 to always prefer).\n"
                     "auto-ports=<dist>,...\n"
@@ -269,7 +260,7 @@ class Upload(Changes):
         @classmethod
         def _get_top_changes(cls, upload_changes):
             """
-            Filter only the first block from the changes (changelog) entry.
+            Filter only the first block from the changes (changelog) entry
 
             Upload changes may include multiple version blocks from
             the changelog (internal porting does it, for example),
@@ -286,7 +277,7 @@ class Upload(Changes):
             return result
 
         def _parse_ancient(self):
-            """Compat parse support for ancient 'magic' options."""
+            """Compat parse support for ancient 'magic' options"""
             def warning(ancient, option):
                 LOG.warning(f"Ancient user option \"{ancient}\" found. Please use option \"{option}\" instead (see user manual).")
 
@@ -319,18 +310,18 @@ class Upload(Changes):
 
             # Validity check for key
             if base_key not in list(self._OPTIONS):
-                raise mini_buildd.HTTPBadRequest(f"Unknown upload option: {key}")
+                raise util.HTTPBadRequest(f"Unknown upload option: {key}")
 
             # Duplicity check
             if key in list(self._options):
-                raise mini_buildd.HTTPBadRequest(f"Duplicate upload option: {key}")
+                raise util.HTTPBadRequest(f"Duplicate upload option: {key}")
 
             # Value conversion check
             converted_value = None
             try:
                 converted_value = self._OPTIONS[base_key](value)
             except BaseException as e:
-                raise mini_buildd.HTTPBadRequest(f"Invalid upload option value: {key}=\"{value}\"") from e
+                raise util.HTTPBadRequest(f"Invalid upload option value: {key}=\"{value}\"") from e
 
             # Handle deprecated options
             if base_key in list(self._OPTIONS_DEPRECATED):
@@ -350,10 +341,10 @@ class Upload(Changes):
             LOG.debug(f"Upload option set: {key}=\"{value}\"")
 
         def get(self, key, alt=None, default=None):
-            """Get first existing option value in this order: key[a], key, default."""
+            """Get first existing option value in this order: key[a], key, default"""
             # Validity check for key
             if key not in list(self._OPTIONS):
-                raise mini_buildd.HTTPInternal(f"Unknown key used for get(): {key}")
+                raise util.HTTPInternal(f"Unknown key used for get(): {key}")
 
             if alt:
                 m_key = f"{key}[{alt}]"
@@ -367,41 +358,39 @@ class Upload(Changes):
         super().__init__(initial_value, **kwargs)
         self.options = self.Options(self)
         # (Optionally map and) check distribution string integrity
-        self.dist = mini_buildd.dist.Dist(mini_buildd.models.repository.map_distribution(self["Distribution"]))
+        self.dist = dist.Dist(util.models().map_distribution(self["Distribution"]))
 
     def check_mode(self, checker, alt, fallback_mode_int):
-        """Get check mode from upload options, with fallback."""
+        """Get check mode from upload options, with fallback"""
         options_mode_str = self.options.get(f"{checker}-mode", alt=alt)
-        fallback_mode_str = mini_buildd.dist.SbuildCheck.Mode(fallback_mode_int).name
-        return mini_buildd.dist.SbuildCheck(checker, options_mode_str if options_mode_str is not None else fallback_mode_str)
+        fallback_mode_str = dist.SbuildCheck.Mode(fallback_mode_int).name
+        return dist.SbuildCheck(checker, options_mode_str if options_mode_str is not None else fallback_mode_str)
 
     def request_builds(self, repository, distribution, suite_option):
-        """
-        Build buildrequest files for all architectures.
-        """
+        """Build buildrequest files for all architectures"""
         # Extra check on all DSC/source package files
         # - Check md5 against possible pool files.
         # - Add missing from pool (i.e., orig.tar.gz).
         # - make sure all files from dsc are actually available
         files_from_pool = []
-        with mini_buildd.fopen(self.dsc_file_path()) as dsc_file:
+        with util.fopen(self.dsc_file_path()) as dsc_file:
             dsc = debian.deb822.Dsc(dsc_file)
 
         for f in dsc["Files"]:
             in_changes = f["name"] in self.get_files(key="name")
             from_pool = False
             for p in glob.glob(os.path.join(repository.mbd_path, "pool", "*", "*", self["Source"], f["name"])):
-                if f["md5sum"] == mini_buildd.misc.Hash(p).md5():
+                if f["md5sum"] == util.Hash(p).md5():
                     if not in_changes:
                         files_from_pool.append(p)
                         from_pool = True
                         LOG.debug(f"Buildrequest: File added from pool: {p}")
                 else:
-                    raise mini_buildd.HTTPBadRequest(f"MD5 mismatch in uploaded dsc vs. pool: {f['name']}")
+                    raise util.HTTPBadRequest(f"MD5 mismatch in uploaded dsc vs. pool: {f['name']}")
 
             # Check that this file is available
             if not in_changes and not from_pool:
-                raise mini_buildd.HTTPBadRequest(f"Missing file '{f['name']}' neither in upload, nor in pool (use '-sa' for uploads with new upstream)")
+                raise util.HTTPBadRequest(f"Missing file '{f['name']}' neither in upload, nor in pool (use '-sa' for uploads with new upstream)")
 
         buildrequest_dict = {}
         for ao in distribution.architectureoption_set.all():
@@ -412,39 +401,38 @@ class Upload(Changes):
                 "Source": self["Source"],
                 "Version": self["Version"],
                 "Architecture": ao.architecture.name,
-                mini_buildd.misc.CField("Timecode").fullname: self.timecode,
+                util.CField("Timecode").fullname: self.timecode,
             })
 
             # Generate config files
-            config_path = path.new_sub([mini_buildd.sbuild.CONFIG_DIR], create=True)
+            config_path = path.new_sub([sbuild.CONFIG_DIR], create=True)
             config_files = {
-                mini_buildd.sbuild.CONFIG_APT_SOURCES_LIST: repository.mbd_get_apt_build_sources_list(distribution, suite_option).get(),
-                mini_buildd.sbuild.CONFIG_APT_PREFERENCES: repository.mbd_get_apt_build_preferences(distribution, suite_option, self.options.get("internal-apt-priority")),
-                mini_buildd.sbuild.CONFIG_APT_KEYS: repository.mbd_get_apt_keys(distribution),
-                mini_buildd.sbuild.CONFIG_SSL_CERT: mini_buildd.http_endpoint().get_certificate(),
-                mini_buildd.sbuild.CONFIG_CHROOT_SETUP_SCRIPT: distribution.chroot_setup_script,
-                mini_buildd.sbuild.CONFIG_SBUILDRC_SNIPPET: distribution.sbuildrc_snippet,
+                sbuild.CONFIG_APT_SOURCES_LIST: repository.mbd_get_apt_build_sources_list(distribution, suite_option).get(),
+                sbuild.CONFIG_APT_PREFERENCES: repository.mbd_get_apt_build_preferences(distribution, suite_option, self.options.get("internal-apt-priority")),
+                sbuild.CONFIG_APT_KEYS: repository.mbd_get_apt_keys(distribution),
+                sbuild.CONFIG_SSL_CERT: util.http_endpoint().get_certificate(),
+                sbuild.CONFIG_CHROOT_SETUP_SCRIPT: distribution.chroot_setup_script,
+                sbuild.CONFIG_SBUILDRC_SNIPPET: distribution.sbuildrc_snippet,
             }
             for file_name, content in config_files.items():
-                with mini_buildd.fopen(config_path.join(file_name), "w") as f:
+                with util.fopen(config_path.join(file_name), "w") as f:
                     f.write(content)
 
             # Generate tar
-            tar = mini_buildd.files.Tar()
-            tar.add([config_path.join(file_name) for file_name in config_files], arcdir=mini_buildd.sbuild.CONFIG_DIR)
+            tar = files.Tar()
+            tar.add([config_path.join(file_name) for file_name in config_files], arcdir=sbuild.CONFIG_DIR)
             tar.add([self.dsc_file_path()])
             tar.add([os.path.join(os.path.dirname(self.dsc_file_path()), f["name"]) for f in dsc.get("Files", [])])
             tar.add(files_from_pool)
 
-            buildrequest.cset("Upload-To", mini_buildd.get_daemon().model.mbd_get_ftp_endpoint().geturl())
-            buildrequest.cset("Packager", mini_buildd.http_endpoint().geturl())
+            buildrequest.cset("Upload-To", util.daemon().model.mbd_get_ftp_endpoint().geturl())
+            buildrequest.cset("Packager", util.http_endpoint().geturl())
             if ao.build_architecture_all:
                 buildrequest.cset("Arch-All", "Yes")
             buildrequest.cset("Build-Dep-Resolver", distribution.get_build_dep_resolver_display())
-            buildrequest.cset("Apt-Allow-Unauthenticated", "1" if distribution.apt_allow_unauthenticated else "0")
 
-            for blocks_option in mini_buildd.sbuild.CONFIG_BLOCKS.extra_options() + mini_buildd.sbuild.SETUP_BLOCKS.extra_options():
-                buildrequest.cset(blocks_option, distribution.mbd_get_extra_option(blocks_option, ""))
+            for block in [sbuild.CONFIG_BLOCKS, sbuild.SETUP_BLOCKS]:
+                buildrequest.cset(block.name, distribution.mbd_get_extra_option(block.name, block.default))
 
             buildrequest.cset("Deb-Build-Options", self.options.get("deb-build-options", ao.architecture.name, distribution.mbd_get_extra_option("Deb-Build-Options", "")))
             buildrequest.cset("Deb-Build-Profiles", self.options.get("deb-build-profiles", ao.architecture.name, distribution.mbd_get_extra_option("Deb-Build-Profiles", "")))
@@ -457,18 +445,20 @@ class Upload(Changes):
 
             buildrequest.cset("Buildlog", os.path.join(buildrequest.bkey, self.dfn.buildlog(ao.architecture.name)))
 
-            builders = mini_buildd.mdls().gnupg.Builders(wake=True, check=True).get(self.dist.codename, ao.architecture.name)
+            builders = util.models().Builders(wake=True, check=True).get(self.dist.codename, ao.architecture.name)
             for _load, builder in sorted(builders.items()):
                 try:
                     buildrequest.cset("Builder", builder["url"])
+                    buildrequest.cset("Buildlog-Building", config.URIS["builds"]["dir"].url_join(buildrequest.cget("Buildlog"), endpoint=net.ClientEndpoint(builder["url"])))
+                    buildrequest.cset("Buildlog-Installed", config.URIS["events"]["dir"].url_join(buildrequest.cget("Buildlog")))
                     buildrequest.save_to(self.events_path.new_sub([ao.architecture.name], create=True), tar)
-                    buildrequest.upload(mini_buildd.net.ClientEndpoint(builder["incoming_url"]))
+                    buildrequest.upload(net.ClientEndpoint(builder["incoming_url"]))
                     buildrequest_dict[ao.architecture.name] = buildrequest
                     break
                 except BaseException as e:
-                    mini_buildd.log_exception(LOG, f"Uploading to '{builder['incoming_url']}' failed", e, level=logging.ERROR)
+                    util.log_exception(LOG, f"Uploading to '{builder['incoming_url']}' failed", e, level=logging.ERROR)
             if ao.architecture.name not in buildrequest_dict:
-                raise mini_buildd.HTTPUnavailable(f"No working builder found for {ao.architecture.name}/{self.dist.codename}")
+                raise util.HTTPUnavailable(f"No working builder found for {ao.architecture.name}/{self.dist.codename}")
         return buildrequest_dict
 
 
@@ -477,27 +467,27 @@ class Buildrequest(Changes):
 
     def __init__(self, initial_value, **kwargs):
         super().__init__(initial_value, **kwargs)
-        self.dist = mini_buildd.dist.Dist(self["Distribution"])
+        self.dist = dist.Dist(self["Distribution"])
 
     def check_mode(self, checker):
-        """Get check mode from checker (lintian, piuparts, autopkgtest)."""
-        return mini_buildd.dist.SbuildCheck(checker, self.cget(f"{checker.capitalize()}-Mode", mini_buildd.dist.SbuildCheck.Mode.DISABLED.name))
+        """Get check mode from checker (lintian, piuparts, autopkgtest)"""
+        return dist.SbuildCheck(checker, self.cget(f"{checker.capitalize()}-Mode", dist.SbuildCheck.Mode.DISABLED.name))
 
     def check_extra_options(self, checker):
-        """Get check mode from checker (lintian, piuparts, autopkgtest)."""
+        """Get check mode from checker (lintian, piuparts, autopkgtest)"""
         return self.cget(f"{checker.capitalize()}-Extra-Options", "")
 
     def gen_buildresult(self):
-        bres_path = self.dfn.changes(self["Architecture"], mini_buildd.changes.Buildresult.FILE_APX)
+        bres_path = self.dfn.changes(self["Architecture"], Buildresult.FILE_APX)
         if os.path.exists(bres_path):
             return Buildresult(bres_path)
-        return Buildresult({k: self[k] for k in ["Distribution", "Source", "Version", "Architecture"] + [mini_buildd.misc.CField(cfield).fullname for cfield in ["Timecode", "Builder", "Buildlog", "Upload-To"]]})
+        return Buildresult({k: self[k] for k in ["Distribution", "Source", "Version", "Architecture"] + [util.CField(cfield).fullname for cfield in ["Timecode", "Builder", "Buildlog", "Buildlog-Installed", "Upload-To"]]})
 
     def schroot_name(self):
         """
-        Schroot name w/o namespace (see ``schroot --list``).
+        Schroot name w/o namespace (see ``schroot --list``)
 
-        Must produce same as :func:`~mini_buildd.models.chroot.Chroot.mbd_schroot_name`.
+        Must produce same as :func:`~models.chroot.Chroot.mbd_schroot_name`.
         """
         return f"mini-buildd-{self.dist.codename}-{self['Architecture']}"
 
@@ -514,7 +504,7 @@ class Buildresult(Changes):
 
         def check(arch, status, checker, mode):
             """
-            Check if arch is allowed to succeed based on check results.
+            Check if arch is allowed to succeed based on check results
 
             Succeeds if
             - the actual check run has no errors or warnings
@@ -536,22 +526,22 @@ class Buildresult(Changes):
 
 
 def incoming2queue(file_path):
-    LOG.info(f"Trying to queue incoming: {file_path}")
+    LOG.debug(f"Trying to queue incoming: {file_path}")
     try:
         if Buildresult.match(file_path):
             changes = Buildresult(file_path)
             changes.move_to_events()
-            mini_buildd.get_daemon().packager.queue.put(changes)
+            util.daemon().packager.queue.put(changes)
         elif Buildrequest.match(file_path):
             changes = Buildrequest(file_path).create_events()
             changes.move_to_builds()
-            mini_buildd.get_daemon().builder.queue.put(changes)
+            util.daemon().builder.queue.put(changes)
         else:  # User Upload
             changes = Upload(file_path)
             changes.move_to_events()
-            mini_buildd.get_daemon().packager.queue.put(changes)
+            util.daemon().packager.queue.put(changes)
     except Exception as e:
         # If it at least qualifies as Changes, still try error/event handling for user experience
         changes = Changes(file_path)
         changes.move_to_events()
-        mini_buildd.get_daemon().events.log(mini_buildd.events.Type.REJECTED, changes, e)
+        util.daemon().events.log(events.Type.REJECTED, changes, e)
