@@ -498,7 +498,7 @@ SETUP = {
                     "chroot": {
                         "options": {
                             "extra_options": ("Debootstrap-Command: /usr/sbin/mini-buildd-debootstrap-uname-2.6\n"
-                                              "Debootstrap-Extra-Options: --include=realpath"),
+                                              "Debootstrap-Extra-Options: --include=realpath,timeout"),
                         },
                     },
                     "lintian_options": {
