@@ -57,7 +57,7 @@ class ExceptionMiddleware():
     def error(cls, request, exception, output="html", status=http.HTTPStatus.INTERNAL_SERVER_ERROR):
         http_exception = util.e2http(exception, status)
         if http_exception.status != http.HTTPStatus.OK:
-            models.mbd_msg_exception(request, exception, "Middleware exception")
+            models.mbd_msg_exception(request, exception, "Middleware exception: ")
 
         return django.template.response.TemplateResponse(request,
                                                          cls.MBD_TEMPLATES[output],
@@ -336,4 +336,6 @@ class APIView(TemplateView):
         # API call output
         if self.template_name is not None:
             return super().get(request, *args, **kwargs)
+        if self.mbd_output == "plain":
+            return django.http.HttpResponse(self.mbd_call.plain(), content_type="text/plain")
         return django.http.JsonResponse(self.mbd_call.result, safe=False)
